#
# spec file for package openslide
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soversion 0
%define libname lib%{name}

Name:           openslide
Version:        3.4.1
Release:        bp156.3.8
Summary:        C library for reading virtual slides
License:        LGPL-2.1-only
Group:          System/Libraries
Url:            http://openslide.org/
Source0:        https://github.com/openslide/openslide/releases/download/v%{version}/openslide-%{version}.tar.xz
BuildRequires:  cairo-devel
BuildRequires:  fdupes
BuildRequires:  gdk-pixbuf-devel
BuildRequires:  glib2-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  libxml2-devel
BuildRequires:  openjpeg2-devel
BuildRequires:  pkg-config
BuildRequires:  sqlite3-devel
BuildRequires:  xz
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The OpenSlide library allows programs to access virtual slide files
regardless of the underlying image format.

%package -n %{libname}%{soversion}
Summary:        C library for reading virtual slides
Group:          System/Libraries

%description -n %{libname}%{soversion}
The OpenSlide library allows programs to access virtual slide files
regardless of the underlying image format.

%package -n %{libname}-devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{soversion} = %{version}
Recommends:     %{libname}-doc = %{version}

%description -n %{libname}-devel
This package contains libraries and header files for
developing applications that use %{name}.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
BuildArch:      noarch

%description doc
This package contains documentation for developing with openslide library.

%package tools
Summary:        Command line tools for %{name}
Group:          Productivity/Graphics/Other
Requires:       %{libname}%{soversion} = %{version}

%description tools
This package contains command line tools for working with virtual slides.

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print
%fdupes -s doc/html/

%clean
rm -rf %{buildroot}

%post -n %{libname}%{soversion} -p /sbin/ldconfig

%postun -n %{libname}%{soversion} -p /sbin/ldconfig

%files -n %{libname}%{soversion}
%defattr(-,root,root)
%{_libdir}/*.so.%{soversion}*

%files -n %{libname}-devel
%defattr(-,root,root)
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files doc
%defattr(-,root,root)
%doc README.txt lgpl-2.1.txt LICENSE.txt CHANGELOG.txt doc/html/

%files tools
%defattr(-,root,root)
%{_bindir}/*
%{_mandir}/man1/openslide*.1.gz

%changelog
* Mon Mar 19 2018 crrodriguez@opensuse.org
- zlib is directly required so it should be in Buildrequires.
* Tue Apr 28 2015 dmitry_r@opensuse.org
- Update to version 3.4.1
  * New formats: Philips TIFF, Ventana TIFF
  * Support OpenJPEG 2.1.0
  * Improve performance of JPEG and JP2K decoding
  * Add openslide.region[i].* properties
  * Improve MATLAB compatibility
  * Enable function deprecation warnings with MSVC
  * Many portability fixes
  * aperio: Detect OpenJPEG chroma subsampling breakage during open
  * aperio: Fill in missing tiles with downsampled data
  * aperio: Report MPP for slides scanned in locales with decimal comma
  * hamamatsu: Support NDPI files > 4 GB
  * hamamatsu: Properly detect NDPI slides produced by NDP.toolkit
  * hamamatsu: Support VMS/VMU slides without a NoLayers key
  * hamamatsu: Report MPP for VMS/VMU
  * leica: Support slides with 2010/03/10 XML namespace
  * leica: Base64-decode leica.barcode property in 2010/10/01 namespace
  * sakura: Support slides with multiple focal planes
  * sakura: Support slides without tile table
  * ventana: Support slides with multiple focal planes
  * ventana: Improve positioning of AOIs within level
  * ventana: Fix failure to recognize macro image on some slides
* Sun Jan 26 2014 dmitry_r@opensuse.org
- Update to version 3.4.0
  * Major internal restructuring
  * New formats: Hamamatsu NDPI, Sakura SVSLIDE, Ventana BIF (preliminary)
  * Add openslide_detect_vendor()
  * Deprecate openslide_can_open() (not very useful and often misused)
  * Document performance considerations for openslide_open()
  * Add properties giving the bounds of the non-empty region of the slide
  * leica: Support multiple main images if their levels are coplanar
  * leica: Use slide size as level size
  * mirax: Support PNG- and BMP-formatted slides
  * mirax: Fix "Expected first 0 value" error opening some slides
  * mirax: Fix incorrect tile placement on some slides without overlaps
  * mirax: Never synthesize downsampled levels
  * Add OPENSLIDE_DEBUG environment variable (OPENSLIDE_DEBUG=? for help)
  * Fix some crashes in error paths
  * Add tests for many error paths
* Sat Apr 13 2013 dmitry_r@opensuse.org
- Update to version 3.3.3
  * Properly handle Aperio JP2K slides with zero-length tiles
  * Support Hamamatsu slides with blank MacroImage key
* Sun Dec  2 2012 dmitry_r@opensuse.org
- Update to version 3.3.2
  * Fix seams in MIRAX 2.2 slides
  * Fix associated image naming in single-level Aperio slides
  * Stop decoding MIRAX tiles outside requested region
  * Stop decoding unneeded tiles during tile-aligned accesses
  * Increase Hamamatsu VMU tile size to reduce rendering overhead
  * Document performance considerations for openslide_can_open()
* Wed Oct 31 2012 dmitry_r@opensuse.org
- Update to version 3.3.1
  * Parallelize concurrent openslide_read_region calls on an openslide_t
  * Eliminate background scanning of tile headers in MIRAX
  * Scan many fewer tiles during first accesses to Hamamatsu VMS
  * Ignore Leica Z-planes other than 0
  * Add experimental tile-size properties
  * Document API thread safety
* Sat Sep 15 2012 dmitry_r@opensuse.org
- Update to version 3.3.0
  * Support Leica SCN format (requires libtiff >= 4) (thanks, Agelos Pappas)
  * Allow opening MIRAX 2.2 slides (though there are seams, bug #92)
  * Add standardized microns-per-pixel and objective-power properties
  * Add "macro" associated image in Trestle
  * Rename "layer" to "level" throughout the API (deprecate "layer" functions;
    remove "layer" properties)
  * Report parse errors in openslide_open() by returning an openslide_t in
    error state
  * Deprecate openslide_get_comment()
  * Add openslide_get_version()
  * Improve command-line tools; add manpages
  * Support building with MinGW-w64; drop CMake, MSVC, mingw32
  * Add tests for many error paths
* Wed Aug 22 2012 dmitry_r@opensuse.org
- Add doc package
- Various spec file cleanups
* Sat Aug 11 2012 dmitry_r@opensuse.org
- Initial package
- Version 3.2.6
